/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.13
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // qrcurls
  0x0,0x0,0x0,0x1f,
  0x69,
  0x6d,0x70,0x6f,0x72,0x74,0x20,0x51,0x74,0x51,0x6d,0x6c,0x20,0x32,0x2e,0x30,0xa,
  0xa,0x51,0x74,0x4f,0x62,0x6a,0x65,0x63,0x74,0x20,0x7b,0xa,0x7d,0xa,
    // qrcurls
  0x0,0x0,0x0,0x1b,
  0x66,
  0x75,0x6e,0x63,0x74,0x69,0x6f,0x6e,0x20,0x73,0x6f,0x6d,0x65,0x46,0x75,0x6e,0x63,
  0x74,0x69,0x6f,0x6e,0x28,0x29,0x20,0x7b,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // data
  0x0,0x4,
  0x0,0x6,0xa8,0xa1,
  0x0,0x64,
  0x0,0x61,0x0,0x74,0x0,0x61,
    // qrcurls.qml
  0x0,0xb,
  0x9,0xc7,0x45,0xbc,
  0x0,0x71,
  0x0,0x72,0x0,0x63,0x0,0x75,0x0,0x72,0x0,0x6c,0x0,0x73,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,0x6c,
    // qrcurls.js
  0x0,0xa,
  0xc,0x9c,0x74,0x53,
  0x0,0x71,
  0x0,0x72,0x0,0x63,0x0,0x75,0x0,0x72,0x0,0x6c,0x0,0x73,0x0,0x2e,0x0,0x6a,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x8c,0xd5,0xec,0xb0,0xe0,
  // :/data
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x8c,0xd5,0xec,0xb0,0xe0,
  // :/data/qrcurls.qml
  0x0,0x0,0x0,0xe,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x8c,0xd5,0xec,0xb0,0xe0,
  // :/data/qrcurls.js
  0x0,0x0,0x0,0x2a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x23,
0x0,0x0,0x1,0x8c,0xd5,0xec,0xb0,0xe0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_qmake_immediate)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_qmake_immediate)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_qmake_immediate)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_qmake_immediate)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_qmake_immediate)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_qmake_immediate)(); }
   } dummy;
}
