/****************************************************************************
** Meta object code from reading C++ file 'qquickflipable_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.13)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/quick/items/qquickflipable_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickflipable_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.13. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QQuickFlipable_t {
    QByteArrayData data[15];
    char stringdata0[134];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QQuickFlipable_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QQuickFlipable_t qt_meta_stringdata_QQuickFlipable = {
    {
QT_MOC_LITERAL(0, 0, 14), // "QQuickFlipable"
QT_MOC_LITERAL(1, 15, 11), // "QML.Element"
QT_MOC_LITERAL(2, 27, 8), // "Flipable"
QT_MOC_LITERAL(3, 36, 12), // "frontChanged"
QT_MOC_LITERAL(4, 49, 0), // ""
QT_MOC_LITERAL(5, 50, 11), // "backChanged"
QT_MOC_LITERAL(6, 62, 11), // "sideChanged"
QT_MOC_LITERAL(7, 74, 15), // "retransformBack"
QT_MOC_LITERAL(8, 90, 5), // "front"
QT_MOC_LITERAL(9, 96, 11), // "QQuickItem*"
QT_MOC_LITERAL(10, 108, 4), // "back"
QT_MOC_LITERAL(11, 113, 4), // "side"
QT_MOC_LITERAL(12, 118, 4), // "Side"
QT_MOC_LITERAL(13, 123, 5), // "Front"
QT_MOC_LITERAL(14, 129, 4) // "Back"

    },
    "QQuickFlipable\0QML.Element\0Flipable\0"
    "frontChanged\0\0backChanged\0sideChanged\0"
    "retransformBack\0front\0QQuickItem*\0"
    "back\0side\0Side\0Front\0Back"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QQuickFlipable[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
       4,   16, // methods
       3,   40, // properties
       1,   52, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,   36,    4, 0x06 /* Public */,
       5,    0,   37,    4, 0x06 /* Public */,
       6,    0,   38,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   39,    4, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,

 // properties: name, type, flags
       8, 0x80000000 | 9, 0x0049510b,
      10, 0x80000000 | 9, 0x0049510b,
      11, 0x80000000 | 12, 0x00495009,

 // properties: notify_signal_id
       0,
       1,
       2,

 // enums: name, alias, flags, count, data
      12,   12, 0x0,    2,   57,

 // enum data: key, value
      13, uint(QQuickFlipable::Front),
      14, uint(QQuickFlipable::Back),

       0        // eod
};

void QQuickFlipable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QQuickFlipable *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->frontChanged(); break;
        case 1: _t->backChanged(); break;
        case 2: _t->sideChanged(); break;
        case 3: _t->retransformBack(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QQuickFlipable::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickFlipable::frontChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QQuickFlipable::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickFlipable::backChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QQuickFlipable::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickFlipable::sideChanged)) {
                *result = 2;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QQuickFlipable *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QQuickItem**>(_v) = _t->front(); break;
        case 1: *reinterpret_cast< QQuickItem**>(_v) = _t->back(); break;
        case 2: *reinterpret_cast< Side*>(_v) = _t->side(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QQuickFlipable *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFront(*reinterpret_cast< QQuickItem**>(_v)); break;
        case 1: _t->setBack(*reinterpret_cast< QQuickItem**>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QQuickFlipable::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_QQuickFlipable.data,
    qt_meta_data_QQuickFlipable,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QQuickFlipable::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickFlipable::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QQuickFlipable.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int QQuickFlipable::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 3;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QQuickFlipable::frontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuickFlipable::backChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuickFlipable::sideChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
