/****************************************************************************
** Meta object code from reading C++ file 'qqmlloggingcategory_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.13)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/qml/qml/qqmlloggingcategory_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qqmlloggingcategory_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.13. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QQmlLoggingCategory_t {
    QByteArrayData data[13];
    char stringdata0[145];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QQmlLoggingCategory_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QQmlLoggingCategory_t qt_meta_stringdata_QQmlLoggingCategory = {
    {
QT_MOC_LITERAL(0, 0, 19), // "QQmlLoggingCategory"
QT_MOC_LITERAL(1, 20, 11), // "QML.Element"
QT_MOC_LITERAL(2, 32, 15), // "LoggingCategory"
QT_MOC_LITERAL(3, 48, 23), // "QML.AddedInMinorVersion"
QT_MOC_LITERAL(4, 72, 1), // "8"
QT_MOC_LITERAL(5, 74, 4), // "name"
QT_MOC_LITERAL(6, 79, 15), // "defaultLogLevel"
QT_MOC_LITERAL(7, 95, 15), // "DefaultLogLevel"
QT_MOC_LITERAL(8, 111, 5), // "Debug"
QT_MOC_LITERAL(9, 117, 4), // "Info"
QT_MOC_LITERAL(10, 122, 7), // "Warning"
QT_MOC_LITERAL(11, 130, 8), // "Critical"
QT_MOC_LITERAL(12, 139, 5) // "Fatal"

    },
    "QQmlLoggingCategory\0QML.Element\0"
    "LoggingCategory\0QML.AddedInMinorVersion\0"
    "8\0name\0defaultLogLevel\0DefaultLogLevel\0"
    "Debug\0Info\0Warning\0Critical\0Fatal"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QQmlLoggingCategory[] = {

 // content:
       8,       // revision
       0,       // classname
       2,   14, // classinfo
       0,    0, // methods
       2,   18, // properties
       1,   26, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,
       3,    4,

 // properties: name, type, flags
       5, QMetaType::QString, 0x00095103,
       6, 0x80000000 | 7, 0x0089510b,

 // properties: revision
       0,
      12,

 // enums: name, alias, flags, count, data
       7,    7, 0x0,    5,   31,

 // enum data: key, value
       8, uint(QQmlLoggingCategory::Debug),
       9, uint(QQmlLoggingCategory::Info),
      10, uint(QQmlLoggingCategory::Warning),
      11, uint(QQmlLoggingCategory::Critical),
      12, uint(QQmlLoggingCategory::Fatal),

       0        // eod
};

void QQmlLoggingCategory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QQmlLoggingCategory *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast< DefaultLogLevel*>(_v) = _t->defaultLogLevel(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QQmlLoggingCategory *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setDefaultLogLevel(*reinterpret_cast< DefaultLogLevel*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QQmlLoggingCategory::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QQmlLoggingCategory.data,
    qt_meta_data_QQmlLoggingCategory,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QQmlLoggingCategory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQmlLoggingCategory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QQmlLoggingCategory.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int QQmlLoggingCategory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    
#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
