/****************************************************************************
** Meta object code from reading C++ file 'qquickscalegrid_p_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.13)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/quick/items/qquickscalegrid_p_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickscalegrid_p_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.13. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QQuickScaleGrid_t {
    QByteArrayData data[13];
    char stringdata0[149];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QQuickScaleGrid_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QQuickScaleGrid_t qt_meta_stringdata_QQuickScaleGrid = {
    {
QT_MOC_LITERAL(0, 0, 15), // "QQuickScaleGrid"
QT_MOC_LITERAL(1, 16, 11), // "QML.Element"
QT_MOC_LITERAL(2, 28, 9), // "anonymous"
QT_MOC_LITERAL(3, 38, 13), // "borderChanged"
QT_MOC_LITERAL(4, 52, 0), // ""
QT_MOC_LITERAL(5, 53, 17), // "leftBorderChanged"
QT_MOC_LITERAL(6, 71, 16), // "topBorderChanged"
QT_MOC_LITERAL(7, 88, 18), // "rightBorderChanged"
QT_MOC_LITERAL(8, 107, 19), // "bottomBorderChanged"
QT_MOC_LITERAL(9, 127, 4), // "left"
QT_MOC_LITERAL(10, 132, 3), // "top"
QT_MOC_LITERAL(11, 136, 5), // "right"
QT_MOC_LITERAL(12, 142, 6) // "bottom"

    },
    "QQuickScaleGrid\0QML.Element\0anonymous\0"
    "borderChanged\0\0leftBorderChanged\0"
    "topBorderChanged\0rightBorderChanged\0"
    "bottomBorderChanged\0left\0top\0right\0"
    "bottom"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QQuickScaleGrid[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
       5,   16, // methods
       4,   46, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,   41,    4, 0x06 /* Public */,
       5,    0,   42,    4, 0x06 /* Public */,
       6,    0,   43,    4, 0x06 /* Public */,
       7,    0,   44,    4, 0x06 /* Public */,
       8,    0,   45,    4, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       9, QMetaType::Int, 0x00495103,
      10, QMetaType::Int, 0x00495103,
      11, QMetaType::Int, 0x00495103,
      12, QMetaType::Int, 0x00495103,

 // properties: notify_signal_id
       1,
       2,
       3,
       4,

       0        // eod
};

void QQuickScaleGrid::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QQuickScaleGrid *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->borderChanged(); break;
        case 1: _t->leftBorderChanged(); break;
        case 2: _t->topBorderChanged(); break;
        case 3: _t->rightBorderChanged(); break;
        case 4: _t->bottomBorderChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QQuickScaleGrid::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickScaleGrid::borderChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QQuickScaleGrid::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickScaleGrid::leftBorderChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QQuickScaleGrid::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickScaleGrid::topBorderChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QQuickScaleGrid::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickScaleGrid::rightBorderChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QQuickScaleGrid::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickScaleGrid::bottomBorderChanged)) {
                *result = 4;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QQuickScaleGrid *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->left(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->top(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->right(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->bottom(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QQuickScaleGrid *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLeft(*reinterpret_cast< int*>(_v)); break;
        case 1: _t->setTop(*reinterpret_cast< int*>(_v)); break;
        case 2: _t->setRight(*reinterpret_cast< int*>(_v)); break;
        case 3: _t->setBottom(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QQuickScaleGrid::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QQuickScaleGrid.data,
    qt_meta_data_QQuickScaleGrid,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QQuickScaleGrid::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickScaleGrid::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QQuickScaleGrid.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuickScaleGrid::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QQuickScaleGrid::borderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuickScaleGrid::leftBorderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuickScaleGrid::topBorderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuickScaleGrid::rightBorderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuickScaleGrid::bottomBorderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
