/****************************************************************************
**
** Copyright (C) 2019 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtQuick module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef PLUGIN_H
#define PLUGIN_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <QtGui/private/qwindow_p.h>
#include <QtQuick/private/qquickwindow_p.h>
#include <QtQuick/private/qquickwindowattached_p.h>
#include <QtQuick/private/qquickscreen_p.h>
#include <QtQuick/private/qquickwindowmodule_p.h>
#include <QtQml/qqml.h>

QT_BEGIN_NAMESPACE

struct QWindowForeign
{
    Q_GADGET
    QML_FOREIGN(QWindow)
    QML_ANONYMOUS
    QML_ADDED_IN_MINOR_VERSION(1)
};

struct QQuickWindowForeign
{
    Q_GADGET
    QML_FOREIGN(QQuickWindow)
    QML_NAMED_ELEMENT(Window)
    QML_ADDED_IN_MINOR_VERSION(0)
    QML_REMOVED_IN_MINOR_VERSION(1)
};

struct QQuickWindowForeignAttached
{
    Q_GADGET
    QML_FOREIGN(QQuickWindowAttached)
    QML_ANONYMOUS
};

struct QQuickScreenInfoForeign
{
    Q_GADGET
    QML_FOREIGN(QQuickScreenInfo)
    QML_NAMED_ELEMENT(ScreenInfo)
    QML_ADDED_IN_MINOR_VERSION(3)
    QML_UNCREATABLE("ScreenInfo can only be used via the attached property.")
};

struct QQuickScreenForeignAttached
{
    Q_GADGET
    QML_FOREIGN(QQuickScreenAttached)
    QML_ANONYMOUS
};

struct QQuickScreenForeign
{
    Q_GADGET
    QML_FOREIGN(QQuickScreen)
    QML_NAMED_ELEMENT(Screen)
    QML_UNCREATABLE("Screen can only be used via the attached property.")
};

struct QQuickWindowQmlImplForeign
{
    Q_GADGET
    QML_FOREIGN(QQuickWindowQmlImpl)
    QML_NAMED_ELEMENT(Window)
    QML_ADDED_IN_MINOR_VERSION(1)
};

struct QQuickRootItemForeign
{
    Q_GADGET
    QML_FOREIGN(QQuickRootItem)
    QML_ANONYMOUS
};

QT_END_NAMESPACE

#endif // PLUGIN_H
